#  Copyright (c) maiot GmbH 2020. All Rights Reserved.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at:
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
#  or implied. See the License for the specific language governing
#  permissions and limitations under the License.

from zenml.components.bulk_inferrer.component import BulkInferrer
from zenml.components.data_gen.component import DataGen
from zenml.components.evaluator.component import Evaluator
from zenml.components.sequencer.component import Sequencer
from zenml.components.split_gen.component import SplitGen
from zenml.components.tokenizer.component import Tokenizer
from zenml.components.trainer.component import Trainer
from zenml.components.transform_simple.component import SimpleTransform
